@@ -1,6 +1,6 @@
 import requests
 import json
-from .Errors.Exceptions import *
+from .Errors import Exceptions
 from random import randint
 class Users:
   def get_display_by_id(id):
@@ -131,7 +131,7 @@ class Users:
       elif API_JSON['isBanned'] == False:
         return False
     except KeyError:
-      raise InvalidUserError(user=username)
+      raise Exceptios.InvalidUserError(user=username)
   def isBanned_by_id(id):
     try:
       API_URL = f"https://users.roblox.com/v1/users/{id}"
@@ -142,4 +142,4 @@ class Users:
       elif API_JSON['isBanned'] == False:
         return False
     except KeyError:
-      raise InvalidUserError(user=id)
\ No newline at end of file
+      raise Exceptions.InvalidUserError(user=id)
\ No newline at end of file
